| faggregate | R Documentation |
Aggregates a mlr3::ResampleResult or mlr3::BenchmarkResult for a single simple measure. Returns the aggregated score for each resample result.
faggregate(obj, measure, conditions = FALSE)
obj |
(mlr3::ResampleResult | mlr3::BenchmarkResult). |
measure |
(mlr3::Measure). |
conditions |
( |
This function is faster than $aggregate() because it does not reassemble the resampling results.
It only works on simple measures which do not require the task, learner, model or train set to be available.
(data.table::data.table())
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.