| mlr3fselect.backup | R Documentation |
This CallbackBatchFSelect writes the mlr3::BenchmarkResult after each batch to disk.
The path must be set, e.g. clbk("mlr3fselect.backup", path = "backup.rds").
The benchmark result is written to a temporary file first and then renamed,
so that a crash while writing does not destroy the backup of the previous batch.
clbk("mlr3fselect.backup", path = "backup.rds")
# Run feature selection on the Palmer Penguins data set
instance = fselect(
fselector = fs("random_search"),
task = tsk("diabetes"),
learner = lrn("classif.rpart"),
resampling = rsmp ("holdout"),
measures = msr("classif.ce"),
term_evals = 4,
callbacks = clbk("mlr3fselect.backup", path = tempfile(fileext = ".rds")))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.