mlr_fselectors_async_design_points: Feature Selection with Asynchronous Design Points

mlr_fselectors_async_design_pointsR Documentation

Feature Selection with Asynchronous Design Points

Description

Subclass for asynchronous design points feature selection.

Dictionary

This FSelector can be instantiated with the associated sugar function fs():

fs("async_design_points")

Parameters

design

data.table::data.table
Design points to try in search, one per row.

Super classes

FSelector -> FSelectorAsync -> FSelectorAsyncFromOptimizerAsync -> FSelectorAsyncDesignPoints

Methods

Public methods

Inherited methods

FSelectorAsyncDesignPoints$new()

Creates a new instance of this R6 class.

Usage
FSelectorAsyncDesignPoints$new()

FSelectorAsyncDesignPoints$clone()

The objects of this class are cloneable with this method.

Usage
FSelectorAsyncDesignPoints$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.

See Also

Other FSelectorAsync: mlr_fselectors_async_exhaustive_search, mlr_fselectors_async_random_search


mlr3fselect documentation built on Aug. 23, 2026, 5:08 p.m.